==> gaudium-0.1.2.tgz: package/lib/gaudium/httpRemoteClient.js <==
var _liburl = require('url')

function HttpMessage()
{
    this._header = {}
}

HttpMessage.prototype = {
    initHeader:function( content_type )
    {
       if ( content_type == null )
       {
              content_type = "text/html"
        }
        this.clearHeader()
        this.appendHeader( { 'content-type' : content_type } )
        this.appendHeader( { 'transfer-encoding' : 'chunked' } )
    },
    clearHeader:function()
    {
           for ( var key in this._header )
           {
                delete this._header[ key ]
           }
           this._header = {}
    },
    appendHeader:function(collection)
    {
           for ( item in collection )
           {
              this._header[item] = collection[item]
           }
    },
    getHeader:function()
    {
           return this._header
    },

    transmit: function( resp, code, data )
    {
        var isBinary = this.getHeader()['content-type'].match(/^text/) == null

        resp.writeHead( code, this.getHeader() )
        if ( isBinary )
        {
           resp.end( data, 'binary' )
           return
        }
        resp.end( data)
    }
}

function HttpRemoteClient(req,resp){
        this.request = req
        this.response = resp
        this.requestURI = _liburl.parse( req.url, true, true )
        var parsed = req.headers['host'].split(':')
        this.host   = parsed[0]
        this.port   =parsed[1]
}

HttpRemoteClient.prototype={
        getPort: function()
        {
             return this.port
        },
        getHost :function()
        {
             return this.host
        },
        getRequestURI:function()
        {
             return this.requestURI
        },
        getRequestChannel:function()
        {
             return this.request
        },
        getResponseChannel:function()
        {
             return this.response
        },
        sendMessage:function( msgStruc )
        {
           var httpMsg = new HttpMessage()
            httpMsg.initHeader()
            httpMsg.appendHeader( msgStruc.header )
            httpMsg.transmit( this.getResponseChannel(), msgStruc.code, msgStruc.data )
        }
}

module.exports = HttpRemoteClient

==> gaudium-0.2.0.tgz: package/lib/gaudium/httpRemoteClient.js <==
var _liburl = require('url')

function HttpMessage(content_type)
{
    this._header = {}
    this.initHeader(content_type)
}

HttpMessage.prototype = {
    initHeader:function( content_type )
    {
       if ( content_type == null )
       {
              content_type = "text/html"
        }
        this.clearHeader()
        this.appendHeader( { 'content-type' : content_type } )
        this.appendHeader( { 'transfer-encoding' : 'chunked' } )
    },
    clearHeader:function()
    {
           for ( var key in this._header )
           {
                delete this._header[ key ]
           }
           this._header = {}
    },
    appendHeader:function(collection)
    {
           for ( item in collection )
           {
              this._header[item] = collection[item]
           }
    },
    getHeader:function()
    {
           return this._header
    },

    transmit: function( resp, msgStruc )
    {
       this.appendHeader( msgStruc.header )

        var isBinary = this.getHeader()['content-type'].match(/^text/) == null

        resp.writeHead( msgStruc.code, this.getHeader() )
        if ( isBinary )
        {
           resp.end( msgStruc.data, 'binary' )
           return
        }
        resp.end( msgStruc.data )
    }
}

function HttpRemoteClient(req,resp){
        this.request = req
        this.response = resp
        this.requestURI = _liburl.parse( req.url, true, true )
        var parsed = req.headers['host'].split(':')
        this.host   = parsed[0]
        this.port   =parsed[1]
}

HttpRemoteClient.prototype={
        getPort: function()
        {
             return this.port
        },
        getHost :function()
        {
             return this.host
        },
        getRequestURI:function()
        {
             return this.requestURI
        },
        getRequestChannel:function()
        {
             return this.request
        },
        getResponseChannel:function()
        {
             return this.response
        },
        sendMessage:function( msgStruc )
        {
           var httpMsg = new HttpMessage()
           httpMsg.transmit( this.getResponseChannel(), msgStruc )
        }
}

module.exports = HttpRemoteClient
